* tests/fun/l2l/Makefile.am,
* mln/fun/l2l/all.hh,
* mln/fun/l2l/essential.hh: remove.
* mln/fun/v2v/all.hh,
* mln/fun/v2v/essential.hh: update includes.
* tests/fun/l2l/wrap.cc,
* mln/fun/l2l/wrap.hh: move...
* tests/fun/v2v/wrap.cc,
* mln/fun/v2v/wrap.hh: ... here.
* mln/make/relabelfun.hh,
* tests/labeling/relabel.cc
* mln/labeling/wrap.hh: use i2v/v2v instead of l2l.
* tests/fun/Makefile.am: remove l2l subdir.
* tests/fun/v2v/Makefile.am: add labeling::wrap test.
---
milena/ChangeLog | 24 ++++++++++++++
milena/headers.mk | 26 +++++++++++++--
milena/mln/fun/l2l/all.hh | 56 ---------------------------------
milena/mln/fun/l2l/essential.hh | 37 ---------------------
milena/mln/fun/v2v/all.hh | 6 ++-
milena/mln/fun/v2v/essential.hh | 9 ++---
milena/mln/fun/{l2l => v2v}/wrap.hh | 14 ++++----
milena/mln/labeling/wrap.hh | 4 +-
milena/mln/make/relabelfun.hh | 26 +++++++-------
milena/tests/fun/Makefile.am | 2 +-
milena/tests/fun/l2l/Makefile.am | 10 ------
milena/tests/fun/v2v/Makefile.am | 4 ++-
milena/tests/fun/{l2l => v2v}/wrap.cc | 0
milena/tests/labeling/relabel.cc | 2 +-
milena/tests/unit_test/unit-tests.mk | 50 ++++++++++++++++++++++++++---
15 files changed, 126 insertions(+), 144 deletions(-)
delete mode 100644 milena/mln/fun/l2l/all.hh
delete mode 100644 milena/mln/fun/l2l/essential.hh
rename milena/mln/fun/{l2l => v2v}/wrap.hh (90%)
delete mode 100644 milena/tests/fun/l2l/Makefile.am
rename milena/tests/fun/{l2l => v2v}/wrap.cc (100%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index b455cd5..f63a227 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,3 +1,27 @@
+2009-04-30 Guillaume Lazzara <lazzara(a)lrde.epita.fr>
+
+ Remove l2l concept.
+
+ * tests/fun/l2l/Makefile.am,
+ * mln/fun/l2l/all.hh,
+ * mln/fun/l2l/essential.hh: remove.
+
+ * mln/fun/v2v/all.hh,
+ * mln/fun/v2v/essential.hh: update includes.
+
+ * tests/fun/l2l/wrap.cc,
+ * mln/fun/l2l/wrap.hh: move...
+ * tests/fun/v2v/wrap.cc,
+ * mln/fun/v2v/wrap.hh: ... here.
+
+ * mln/make/relabelfun.hh,
+ * tests/labeling/relabel.cc,
+ * mln/labeling/wrap.hh: use i2v/v2v instead of l2l.
+
+ * tests/fun/Makefile.am: remove l2l subdir.
+
+ * tests/fun/v2v/Makefile.am: add labeling::wrap test.
+
2009-04-30 Thierry Geraud <thierry.geraud(a)lrde.epita.fr>
Cleanup accu::image and add take_n_times.
diff --git a/milena/headers.mk b/milena/headers.mk
index 733a334..bc25a88 100644
--- a/milena/headers.mk
+++ b/milena/headers.mk
@@ -58,6 +58,14 @@ mln/literal/white.hh \
mln/literal/essential.hh \
mln/world/binary_2d/subsample.hh \
mln/world/binary_2d/projected_histo.hh \
+mln/world/inter_pixel/neighb2d.hh \
+mln/world/inter_pixel/full.hh \
+mln/world/inter_pixel/display_edge.hh \
+mln/world/inter_pixel/dim2/is_pixel.hh \
+mln/world/inter_pixel/dim2/all.hh \
+mln/world/inter_pixel/dim2/is_edge.hh \
+mln/world/inter_pixel/dim2/is_dot.hh \
+mln/world/inter_pixel/dim2/is_row_odd.hh \
mln/registration/get_rtransf.hh \
mln/registration/internal/rms.hh \
mln/registration/get_rot.hh \
@@ -206,6 +214,7 @@ mln/fun/p2p/all.hh \
mln/fun/p2p/translation.hh \
mln/fun/p2p/mirror.hh \
mln/fun/accu_result.hh \
+mln/fun/binary_param.hh \
mln/fun/x2p/closest_point.hh \
mln/fun/x2p/all.hh \
mln/fun/x2p/essential.hh \
@@ -229,6 +238,7 @@ mln/fun/internal/resolve.hh \
mln/fun/internal/selector.hh \
mln/fun/spe/binary.hh \
mln/fun/spe/unary.hh \
+mln/fun/unary_param.hh \
mln/fun/v2w_w2v/norm.hh \
mln/fun/p2v/ternary.hh \
mln/fun/p2v/iota.hh \
@@ -242,6 +252,9 @@ mln/fun/math/abs.hh \
mln/fun/math/sup.hh \
mln/fun/math/cos.hh \
mln/fun/math/inf.hh \
+mln/fun/point/row.hh \
+mln/fun/point/sli.hh \
+mln/fun/point/col.hh \
mln/fun/v2b/lnot.hh \
mln/fun/v2b/all.hh \
mln/fun/v2b/threshold.hh \
@@ -258,6 +271,7 @@ mln/fun/v2v/rgb_to_hsl.hh \
mln/fun/v2v/cast.hh \
mln/fun/v2v/ch_function_value.hh \
mln/fun/v2v/rgb_to_hsi.hh \
+mln/fun/v2v/wrap.hh \
mln/fun/v2v/enc.hh \
mln/fun/v2v/projection.hh \
mln/fun/v2v/convert.hh \
@@ -276,9 +290,6 @@ mln/fun/i2v/all.hh \
mln/fun/i2v/array.hh \
mln/fun/i2v/all_to.hh \
mln/fun/i2v/essential.hh \
-mln/fun/l2l/all.hh \
-mln/fun/l2l/wrap.hh \
-mln/fun/l2l/essential.hh \
mln/fun/x2x/composed.hh \
mln/fun/x2x/all.hh \
mln/fun/x2x/translation.hh \
@@ -657,6 +668,9 @@ mln/algebra/h_mat.hh \
mln/algebra/quat.hh \
mln/algebra/essential.hh \
mln/linear/gaussian_directional_2d.hh \
+mln/linear/gaussian/internal/coefficients.hh \
+mln/linear/gaussian/filter.hh \
+mln/linear/gaussian/impl.hh \
mln/linear/convolve_2x1d.hh \
mln/linear/all.hh \
mln/linear/ch_convolve.hh \
@@ -1019,6 +1033,7 @@ mln/core/image/obased_rle_image.hh \
mln/core/image/mono_obased_rle_image.hh \
mln/core/image/interpolated.hh \
mln/core/image/lazy_image.hh \
+mln/core/image/graph_window_if_piter.hh \
mln/core/image/t_image.hh \
mln/core/image/hexa_piter.hh \
mln/core/image/edge_image.hh \
@@ -1034,6 +1049,7 @@ mln/core/image/rle_encode.hh \
mln/core/image/complex_window_piter.hh \
mln/core/image/tr_image.hh \
mln/core/image/thrubin_morpher.hh \
+mln/core/image/graph_elt_window_if.hh \
mln/core/image/sub_image.hh \
mln/core/image/rle_image.hh \
mln/core/image/thru_morpher.hh \
@@ -1105,9 +1121,11 @@ mln/arith/plus.hh \
mln/arith/revert.spe.hh \
mln/arith/times.spe.hh \
mln/arith/all.hh \
+mln/arith/div.spe.hh \
mln/arith/times.hh \
mln/arith/diff_abs.hh \
mln/arith/minus.hh \
+mln/arith/div.hh \
mln/arith/min.hh \
mln/arith/revert.hh \
mln/arith/essential.hh \
@@ -1189,9 +1207,11 @@ mln/estim/all.hh \
mln/estim/sum.hh \
mln/estim/mean.hh \
mln/estim/essential.hh \
+mln/graph/all.hh \
mln/graph/attribute/representative.hh \
mln/graph/attribute/card.hh \
mln/graph/compute.hh \
+mln/graph/essential.hh \
mln/set/uni.hh \
mln/set/unique.hh \
mln/set/inter.hh \
diff --git a/milena/mln/fun/l2l/all.hh b/milena/mln/fun/l2l/all.hh
deleted file mode 100644
index c6d2328..0000000
--- a/milena/mln/fun/l2l/all.hh
+++ /dev/null
@@ -1,56 +0,0 @@
-// Copyright (C) 2008, 2009 EPITA Research and Development Laboratory
-// (LRDE)
-//
-// This file is part of the Olena Library. This library is free
-// software; you can redistribute it and/or modify it under the terms
-// of the GNU General Public License version 2 as published by the
-// Free Software Foundation.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this library; see the file COPYING. If not, write to
-// the Free Software Foundation, 51 Franklin Street, Fifth Floor,
-// Boston, MA 02111-1307, USA.
-//
-// As a special exception, you may use this file as part of a free
-// software library without restriction. Specifically, if other files
-// instantiate templates or use macros or inline functions from this
-// file, or you compile this file and link it with other files to
-// produce an executable, this file does not by itself cause the
-// resulting executable to be covered by the GNU General Public
-// License. This exception does not however invalidate any other
-// reasons why the executable file might be covered by the GNU General
-// Public License.
-
-#ifndef MLN_FUN_L2L_ALL_HH
-# define MLN_FUN_L2L_ALL_HH
-
-/// \file mln/fun/l2l/all.hh
-///
-/// File that includes all functions from index to value.
-
-
-namespace mln
-{
-
- namespace fun
- {
-
- /// Namespace of functions from label to label.
- namespace l2l
- {
- }
- }
-
-}
-
-
-# include <mln/fun/l2l/wrap.hh>
-
-
-
-#endif // ! MLN_FUN_L2L_ALL_HH
diff --git a/milena/mln/fun/l2l/essential.hh b/milena/mln/fun/l2l/essential.hh
deleted file mode 100644
index 6ca53c0..0000000
--- a/milena/mln/fun/l2l/essential.hh
+++ /dev/null
@@ -1,37 +0,0 @@
-// Copyright (C) 2008 EPITA Research and Development Laboratory (LRDE)
-//
-// This file is part of the Olena Library. This library is free
-// software; you can redistribute it and/or modify it under the terms
-// of the GNU General Public License version 2 as published by the
-// Free Software Foundation.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this library; see the file COPYING. If not, write to
-// the Free Software Foundation, 51 Franklin Street, Fifth Floor,
-// Boston, MA 02111-1307, USA.
-//
-// As a special exception, you may use this file as part of a free
-// software library without restriction. Specifically, if other files
-// instantiate templates or use macros or inline functions from this
-// file, or you compile this file and link it with other files to
-// produce an executable, this file does not by itself cause the
-// resulting executable to be covered by the GNU General Public
-// License. This exception does not however invalidate any other
-// reasons why the executable file might be covered by the GNU General
-// Public License.
-
-#ifndef MLN_FUN_L2L_ESSENTIAL_HH
-# define MLN_FUN_L2L_ESSENTIAL_HH
-
-/// \file mln/fun/l2l/essential.hh
-///
-/// File that includes essential functions from label to label.
-
-# include <mln/fun/l2l/all.hh>
-
-#endif // ! MLN_FUN_L2L_ESSENTIAL_HH
diff --git a/milena/mln/fun/v2v/all.hh b/milena/mln/fun/v2v/all.hh
index 3b526dd..2d14054 100644
--- a/milena/mln/fun/v2v/all.hh
+++ b/milena/mln/fun/v2v/all.hh
@@ -40,7 +40,9 @@ namespace mln
namespace fun
{
- /// Namespace of functions from value to value.
+ /// \brief Namespace of functions from value to value.
+ ///
+ /// \ingroup modfun
namespace v2v {}
}
@@ -58,7 +60,7 @@ namespace mln
# include <mln/fun/v2v/projection.hh>
# include <mln/fun/v2v/rgb_to_hsi.hh>
# include <mln/fun/v2v/saturate.hh>
-
+# include <mln/fun/v2v/wrap.hh>
#endif // ! MLN_FUN_V2V_ALL_HH
diff --git a/milena/mln/fun/v2v/essential.hh b/milena/mln/fun/v2v/essential.hh
index 6687d6f..513be84 100644
--- a/milena/mln/fun/v2v/essential.hh
+++ b/milena/mln/fun/v2v/essential.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2008 EPITA Research and Development Laboratory
+// Copyright (C) 2008, 2009 EPITA Research and Development Laboratory
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -28,10 +28,9 @@
#ifndef MLN_FUN_V2V_ESSENTIAL_HH
# define MLN_FUN_V2V_ESSENTIAL_HH
-/*! \file mln/fun/v2v/essential.hh
- *
- * \brief File that includes essential functions from value to value.
- */
+/// \file mln/fun/v2v/essential.hh
+///
+/// \brief File that includes essential functions from value to value.
# include <mln/fun/v2v/abs.hh>
# include <mln/fun/v2v/cast.hh>
diff --git a/milena/mln/labeling/wrap.hh b/milena/mln/labeling/wrap.hh
index 5a29870..74683b0 100644
--- a/milena/mln/labeling/wrap.hh
+++ b/milena/mln/labeling/wrap.hh
@@ -36,7 +36,7 @@
# include <mln/core/concept/image.hh>
# include <mln/level/transform.hh>
-# include <mln/fun/l2l/wrap.hh>
+# include <mln/fun/v2v/wrap.hh>
# include <mln/metal/converts_to.hh>
# include <mln/metal/is_a.hh>
# include <mln/value/label_8.hh>
@@ -82,7 +82,7 @@ namespace mln
mln_precondition(exact(input).is_valid());
(void) value_type;
- mln_ch_value(I,V) output = level::transform(input, fun::l2l::wrap<V>());
+ mln_ch_value(I,V) output = level::transform(input, fun::v2v::wrap<V>());
trace::exiting("labeling::wrap");
return output;
diff --git a/milena/mln/make/relabelfun.hh b/milena/mln/make/relabelfun.hh
index 0e0ff3e..19b072d 100644
--- a/milena/mln/make/relabelfun.hh
+++ b/milena/mln/make/relabelfun.hh
@@ -42,12 +42,12 @@ namespace mln
namespace make
{
- /// Create a l2l function from a v2b function.
+ /// Create a i2v function from a v2b function.
/// This function can be used to relabel a labeled image.
///
/// \param[in] f a v2b function.
///
- /// \return a l2l function.
+ /// \return a i2v function.
///
/// \sa mln::labeling::relabel
template <unsigned n, typename F>
@@ -56,12 +56,12 @@ namespace mln
const value::label<n>& nlabels,
value::label<n>& new_nlabels);
- /// Create a l2l function from a v2v function.
+ /// Create a i2v function from a v2v function.
/// This function can be used to relabel a labeled image.
///
/// \param[in] f a v2v function.
///
- /// \return a l2l function.
+ /// \return a i2v function.
///
/// \sa mln::labeling::relabel
template <unsigned n, typename F>
@@ -86,15 +86,15 @@ namespace mln
value::label<n> tmp_nlabels = literal::zero;
typedef value::label<n> label_t;
- fun::i2v::array<label_t> fl2l(nlabels.next(), literal::zero);
+ fun::i2v::array<label_t> fi2v(nlabels.next(), literal::zero);
for (label_t i = 1; i <= nlabels; ++i)
if (fv2b(i))
{
- fl2l(i) = ++tmp_nlabels;
+ fi2v(i) = ++tmp_nlabels;
}
new_nlabels = tmp_nlabels;
trace::exiting("make::relabelfun");
- return fl2l;
+ return fi2v;
}
@@ -111,18 +111,18 @@ namespace mln
value::label<n> tmp_nlabels = literal::zero;
typedef value::label<n> label_t;
- fun::i2v::array<label_t> fl2l(nlabels.next(), literal::zero);
+ fun::i2v::array<label_t> fi2v(nlabels.next(), literal::zero);
for (label_t i = 1; i < nlabels.next(); ++i)
- if (fl2l(fv2v(i)) == literal::zero)
+ if (fi2v(fv2v(i)) == literal::zero)
{
- fl2l(fv2v(i)) = ++tmp_nlabels;
- fl2l(i) = tmp_nlabels;
+ fi2v(fv2v(i)) = ++tmp_nlabels;
+ fi2v(i) = tmp_nlabels;
}
else
- fl2l(i) = fl2l(fv2v(i));
+ fi2v(i) = fi2v(fv2v(i));
new_nlabels = tmp_nlabels;
trace::exiting("make::relabelfun");
- return fl2l;
+ return fi2v;
}
# endif // ! MLN_INCLUDE_ONLY
diff --git a/milena/tests/fun/Makefile.am b/milena/tests/fun/Makefile.am
index 6d856fd..4ea605e 100644
--- a/milena/tests/fun/Makefile.am
+++ b/milena/tests/fun/Makefile.am
@@ -2,4 +2,4 @@
include $(top_srcdir)/milena/tests/tests.mk
-SUBDIRS = i2v p2b l2l p2p p2v v2v vv2v x2x
+SUBDIRS = i2v p2b p2p p2v v2v vv2v x2x
diff --git a/milena/tests/fun/l2l/Makefile.am b/milena/tests/fun/l2l/Makefile.am
deleted file mode 100644
index d7872b4..0000000
--- a/milena/tests/fun/l2l/Makefile.am
+++ /dev/null
@@ -1,10 +0,0 @@
-## Process this file through Automake to create Makefile.in -*- Makefile -*-
-
-include $(top_srcdir)/milena/tests/tests.mk
-
-check_PROGRAMS = \
- wrap
-
-wrap_SOURCES = wrap.cc
-
-TESTS = $(check_PROGRAMS)
diff --git a/milena/tests/fun/v2v/Makefile.am b/milena/tests/fun/v2v/Makefile.am
index 70042a3..7e236f0 100644
--- a/milena/tests/fun/v2v/Makefile.am
+++ b/milena/tests/fun/v2v/Makefile.am
@@ -5,10 +5,12 @@ include $(top_srcdir)/milena/tests/tests.mk
check_PROGRAMS = \
norm \
projection \
- rgb_hsi_conversion
+ rgb_hsi_conversion \
+ wrap
norm_SOURCES = norm.cc
projection_SOURCES = projection.cc
rgb_hsi_conversion_SOURCES = rgb_hsi_conversion.cc
+wrap_SOURCES = wrap.cc
TESTS = $(check_PROGRAMS)
diff --git a/milena/tests/fun/l2l/wrap.cc b/milena/tests/fun/v2v/wrap.cc
similarity index 100%
rename from milena/tests/fun/l2l/wrap.cc
rename to milena/tests/fun/v2v/wrap.cc
diff --git a/milena/tests/labeling/relabel.cc b/milena/tests/labeling/relabel.cc
index 3ffd9c3..3be29a1 100644
--- a/milena/tests/labeling/relabel.cc
+++ b/milena/tests/labeling/relabel.cc
@@ -37,7 +37,7 @@
#include <mln/debug/println.hh>
-struct not_to_remove : public mln::Function_l2b< not_to_remove >
+struct not_to_remove : public mln::Function_v2b< not_to_remove >
{
bool operator()(const mln::value::label_16& l) const
{
diff --git a/milena/tests/unit_test/unit-tests.mk b/milena/tests/unit_test/unit-tests.mk
index 844b37f..c74cb9a 100644
--- a/milena/tests/unit_test/unit-tests.mk
+++ b/milena/tests/unit_test/unit-tests.mk
@@ -56,6 +56,14 @@ mln_literal_white \
mln_literal_essential \
mln_world_binary_2d_subsample \
mln_world_binary_2d_projected_histo \
+mln_world_inter_pixel_neighb2d \
+mln_world_inter_pixel_full \
+mln_world_inter_pixel_display_edge \
+mln_world_inter_pixel_dim2_is_pixel \
+mln_world_inter_pixel_dim2_all \
+mln_world_inter_pixel_dim2_is_edge \
+mln_world_inter_pixel_dim2_is_dot \
+mln_world_inter_pixel_dim2_is_row_odd \
mln_registration_get_rtransf \
mln_registration_internal_rms \
mln_registration_get_rot \
@@ -201,6 +209,7 @@ mln_fun_p2p_all \
mln_fun_p2p_translation \
mln_fun_p2p_mirror \
mln_fun_accu_result \
+mln_fun_binary_param \
mln_fun_x2p_closest_point \
mln_fun_x2p_all \
mln_fun_x2p_essential \
@@ -224,6 +233,7 @@ mln_fun_internal_resolve \
mln_fun_internal_selector \
mln_fun_spe_binary \
mln_fun_spe_unary \
+mln_fun_unary_param \
mln_fun_v2w_w2v_norm \
mln_fun_p2v_ternary \
mln_fun_p2v_iota \
@@ -237,6 +247,9 @@ mln_fun_math_abs \
mln_fun_math_sup \
mln_fun_math_cos \
mln_fun_math_inf \
+mln_fun_point_row \
+mln_fun_point_sli \
+mln_fun_point_col \
mln_fun_v2b_lnot \
mln_fun_v2b_all \
mln_fun_v2b_threshold \
@@ -253,6 +266,7 @@ mln_fun_v2v_rgb_to_hsl \
mln_fun_v2v_cast \
mln_fun_v2v_ch_function_value \
mln_fun_v2v_rgb_to_hsi \
+mln_fun_v2v_wrap \
mln_fun_v2v_enc \
mln_fun_v2v_projection \
mln_fun_v2v_convert \
@@ -271,9 +285,6 @@ mln_fun_i2v_all \
mln_fun_i2v_array \
mln_fun_i2v_all_to \
mln_fun_i2v_essential \
-mln_fun_l2l_all \
-mln_fun_l2l_wrap \
-mln_fun_l2l_essential \
mln_fun_x2x_composed \
mln_fun_x2x_all \
mln_fun_x2x_translation \
@@ -650,6 +661,9 @@ mln_algebra_h_mat \
mln_algebra_quat \
mln_algebra_essential \
mln_linear_gaussian_directional_2d \
+mln_linear_gaussian_internal_coefficients \
+mln_linear_gaussian_filter \
+mln_linear_gaussian_impl \
mln_linear_convolve_2x1d \
mln_linear_all \
mln_linear_ch_convolve \
@@ -994,6 +1008,7 @@ mln_core_image_obased_rle_image \
mln_core_image_mono_obased_rle_image \
mln_core_image_interpolated \
mln_core_image_lazy_image \
+mln_core_image_graph_window_if_piter \
mln_core_image_t_image \
mln_core_image_hexa_piter \
mln_core_image_edge_image \
@@ -1009,6 +1024,7 @@ mln_core_image_rle_encode \
mln_core_image_complex_window_piter \
mln_core_image_tr_image \
mln_core_image_thrubin_morpher \
+mln_core_image_graph_elt_window_if \
mln_core_image_sub_image \
mln_core_image_rle_image \
mln_core_image_thru_morpher \
@@ -1079,6 +1095,7 @@ mln_arith_all \
mln_arith_times \
mln_arith_diff_abs \
mln_arith_minus \
+mln_arith_div \
mln_arith_min \
mln_arith_revert \
mln_arith_essential \
@@ -1156,9 +1173,11 @@ mln_estim_all \
mln_estim_sum \
mln_estim_mean \
mln_estim_essential \
+mln_graph_all \
mln_graph_attribute_representative \
mln_graph_attribute_card \
mln_graph_compute \
+mln_graph_essential \
mln_set_uni \
mln_set_unique \
mln_set_inter \
@@ -1241,6 +1260,14 @@ mln_literal_white_SOURCES = mln_literal_white.cc
mln_literal_essential_SOURCES = mln_literal_essential.cc
mln_world_binary_2d_subsample_SOURCES = mln_world_binary_2d_subsample.cc
mln_world_binary_2d_projected_histo_SOURCES = mln_world_binary_2d_projected_histo.cc
+mln_world_inter_pixel_neighb2d_SOURCES = mln_world_inter_pixel_neighb2d.cc
+mln_world_inter_pixel_full_SOURCES = mln_world_inter_pixel_full.cc
+mln_world_inter_pixel_display_edge_SOURCES = mln_world_inter_pixel_display_edge.cc
+mln_world_inter_pixel_dim2_is_pixel_SOURCES = mln_world_inter_pixel_dim2_is_pixel.cc
+mln_world_inter_pixel_dim2_all_SOURCES = mln_world_inter_pixel_dim2_all.cc
+mln_world_inter_pixel_dim2_is_edge_SOURCES = mln_world_inter_pixel_dim2_is_edge.cc
+mln_world_inter_pixel_dim2_is_dot_SOURCES = mln_world_inter_pixel_dim2_is_dot.cc
+mln_world_inter_pixel_dim2_is_row_odd_SOURCES = mln_world_inter_pixel_dim2_is_row_odd.cc
mln_registration_get_rtransf_SOURCES = mln_registration_get_rtransf.cc
mln_registration_internal_rms_SOURCES = mln_registration_internal_rms.cc
mln_registration_get_rot_SOURCES = mln_registration_get_rot.cc
@@ -1386,6 +1413,7 @@ mln_fun_p2p_all_SOURCES = mln_fun_p2p_all.cc
mln_fun_p2p_translation_SOURCES = mln_fun_p2p_translation.cc
mln_fun_p2p_mirror_SOURCES = mln_fun_p2p_mirror.cc
mln_fun_accu_result_SOURCES = mln_fun_accu_result.cc
+mln_fun_binary_param_SOURCES = mln_fun_binary_param.cc
mln_fun_x2p_closest_point_SOURCES = mln_fun_x2p_closest_point.cc
mln_fun_x2p_all_SOURCES = mln_fun_x2p_all.cc
mln_fun_x2p_essential_SOURCES = mln_fun_x2p_essential.cc
@@ -1409,6 +1437,7 @@ mln_fun_internal_resolve_SOURCES = mln_fun_internal_resolve.cc
mln_fun_internal_selector_SOURCES = mln_fun_internal_selector.cc
mln_fun_spe_binary_SOURCES = mln_fun_spe_binary.cc
mln_fun_spe_unary_SOURCES = mln_fun_spe_unary.cc
+mln_fun_unary_param_SOURCES = mln_fun_unary_param.cc
mln_fun_v2w_w2v_norm_SOURCES = mln_fun_v2w_w2v_norm.cc
mln_fun_p2v_ternary_SOURCES = mln_fun_p2v_ternary.cc
mln_fun_p2v_iota_SOURCES = mln_fun_p2v_iota.cc
@@ -1422,6 +1451,9 @@ mln_fun_math_abs_SOURCES = mln_fun_math_abs.cc
mln_fun_math_sup_SOURCES = mln_fun_math_sup.cc
mln_fun_math_cos_SOURCES = mln_fun_math_cos.cc
mln_fun_math_inf_SOURCES = mln_fun_math_inf.cc
+mln_fun_point_row_SOURCES = mln_fun_point_row.cc
+mln_fun_point_sli_SOURCES = mln_fun_point_sli.cc
+mln_fun_point_col_SOURCES = mln_fun_point_col.cc
mln_fun_v2b_lnot_SOURCES = mln_fun_v2b_lnot.cc
mln_fun_v2b_all_SOURCES = mln_fun_v2b_all.cc
mln_fun_v2b_threshold_SOURCES = mln_fun_v2b_threshold.cc
@@ -1438,6 +1470,7 @@ mln_fun_v2v_rgb_to_hsl_SOURCES = mln_fun_v2v_rgb_to_hsl.cc
mln_fun_v2v_cast_SOURCES = mln_fun_v2v_cast.cc
mln_fun_v2v_ch_function_value_SOURCES = mln_fun_v2v_ch_function_value.cc
mln_fun_v2v_rgb_to_hsi_SOURCES = mln_fun_v2v_rgb_to_hsi.cc
+mln_fun_v2v_wrap_SOURCES = mln_fun_v2v_wrap.cc
mln_fun_v2v_enc_SOURCES = mln_fun_v2v_enc.cc
mln_fun_v2v_projection_SOURCES = mln_fun_v2v_projection.cc
mln_fun_v2v_convert_SOURCES = mln_fun_v2v_convert.cc
@@ -1456,9 +1489,6 @@ mln_fun_i2v_all_SOURCES = mln_fun_i2v_all.cc
mln_fun_i2v_array_SOURCES = mln_fun_i2v_array.cc
mln_fun_i2v_all_to_SOURCES = mln_fun_i2v_all_to.cc
mln_fun_i2v_essential_SOURCES = mln_fun_i2v_essential.cc
-mln_fun_l2l_all_SOURCES = mln_fun_l2l_all.cc
-mln_fun_l2l_wrap_SOURCES = mln_fun_l2l_wrap.cc
-mln_fun_l2l_essential_SOURCES = mln_fun_l2l_essential.cc
mln_fun_x2x_composed_SOURCES = mln_fun_x2x_composed.cc
mln_fun_x2x_all_SOURCES = mln_fun_x2x_all.cc
mln_fun_x2x_translation_SOURCES = mln_fun_x2x_translation.cc
@@ -1835,6 +1865,9 @@ mln_algebra_h_mat_SOURCES = mln_algebra_h_mat.cc
mln_algebra_quat_SOURCES = mln_algebra_quat.cc
mln_algebra_essential_SOURCES = mln_algebra_essential.cc
mln_linear_gaussian_directional_2d_SOURCES = mln_linear_gaussian_directional_2d.cc
+mln_linear_gaussian_internal_coefficients_SOURCES =
mln_linear_gaussian_internal_coefficients.cc
+mln_linear_gaussian_filter_SOURCES = mln_linear_gaussian_filter.cc
+mln_linear_gaussian_impl_SOURCES = mln_linear_gaussian_impl.cc
mln_linear_convolve_2x1d_SOURCES = mln_linear_convolve_2x1d.cc
mln_linear_all_SOURCES = mln_linear_all.cc
mln_linear_ch_convolve_SOURCES = mln_linear_ch_convolve.cc
@@ -2179,6 +2212,7 @@ mln_core_image_obased_rle_image_SOURCES =
mln_core_image_obased_rle_image.cc
mln_core_image_mono_obased_rle_image_SOURCES = mln_core_image_mono_obased_rle_image.cc
mln_core_image_interpolated_SOURCES = mln_core_image_interpolated.cc
mln_core_image_lazy_image_SOURCES = mln_core_image_lazy_image.cc
+mln_core_image_graph_window_if_piter_SOURCES = mln_core_image_graph_window_if_piter.cc
mln_core_image_t_image_SOURCES = mln_core_image_t_image.cc
mln_core_image_hexa_piter_SOURCES = mln_core_image_hexa_piter.cc
mln_core_image_edge_image_SOURCES = mln_core_image_edge_image.cc
@@ -2194,6 +2228,7 @@ mln_core_image_rle_encode_SOURCES = mln_core_image_rle_encode.cc
mln_core_image_complex_window_piter_SOURCES = mln_core_image_complex_window_piter.cc
mln_core_image_tr_image_SOURCES = mln_core_image_tr_image.cc
mln_core_image_thrubin_morpher_SOURCES = mln_core_image_thrubin_morpher.cc
+mln_core_image_graph_elt_window_if_SOURCES = mln_core_image_graph_elt_window_if.cc
mln_core_image_sub_image_SOURCES = mln_core_image_sub_image.cc
mln_core_image_rle_image_SOURCES = mln_core_image_rle_image.cc
mln_core_image_thru_morpher_SOURCES = mln_core_image_thru_morpher.cc
@@ -2264,6 +2299,7 @@ mln_arith_all_SOURCES = mln_arith_all.cc
mln_arith_times_SOURCES = mln_arith_times.cc
mln_arith_diff_abs_SOURCES = mln_arith_diff_abs.cc
mln_arith_minus_SOURCES = mln_arith_minus.cc
+mln_arith_div_SOURCES = mln_arith_div.cc
mln_arith_min_SOURCES = mln_arith_min.cc
mln_arith_revert_SOURCES = mln_arith_revert.cc
mln_arith_essential_SOURCES = mln_arith_essential.cc
@@ -2341,9 +2377,11 @@ mln_estim_all_SOURCES = mln_estim_all.cc
mln_estim_sum_SOURCES = mln_estim_sum.cc
mln_estim_mean_SOURCES = mln_estim_mean.cc
mln_estim_essential_SOURCES = mln_estim_essential.cc
+mln_graph_all_SOURCES = mln_graph_all.cc
mln_graph_attribute_representative_SOURCES = mln_graph_attribute_representative.cc
mln_graph_attribute_card_SOURCES = mln_graph_attribute_card.cc
mln_graph_compute_SOURCES = mln_graph_compute.cc
+mln_graph_essential_SOURCES = mln_graph_essential.cc
mln_set_uni_SOURCES = mln_set_uni.cc
mln_set_unique_SOURCES = mln_set_unique.cc
mln_set_inter_SOURCES = mln_set_inter.cc
diff --git a/milena/mln/fun/l2l/wrap.hh b/milena/mln/fun/v2v/wrap.hh
similarity index 90%
rename from milena/mln/fun/l2l/wrap.hh
rename to milena/mln/fun/v2v/wrap.hh
index e7c0ad2..bfa49e0 100644
--- a/milena/mln/fun/l2l/wrap.hh
+++ b/milena/mln/fun/v2v/wrap.hh
@@ -25,10 +25,10 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef MLN_FUN_L2L_WRAP_HH
-# define MLN_FUN_L2L_WRAP_HH
+#ifndef MLN_FUN_V2V_WRAP_HH
+# define MLN_FUN_V2V_WRAP_HH
-/// \file mln/fun/l2l/wrap.hh
+/// \file mln/fun/v2v/wrap.hh
///
/// Function to wrap labels such as 0 -> 0 and [1, lmax] maps to [1,
/// Lmax] (using modulus).
@@ -46,11 +46,11 @@ namespace mln
namespace fun
{
- namespace l2l
+ namespace v2v
{
template <typename L>
- struct wrap : public Function_l2l< wrap<L> >
+ struct wrap : public Function_v2v< wrap<L> >
{
public:
@@ -77,11 +77,11 @@ namespace mln
# endif // ! MLN_INCLUDE_ONLY
- } // end of namespace mln::fun::l2l
+ } // end of namespace mln::fun::v2v
} // end of namespace mln::fun
} // end of namespace mln
-#endif // ! MLN_FUN_L2L_WRAP_HH
+#endif // ! MLN_FUN_V2V_WRAP_HH
--
1.5.6.5